InputLoadFlow

Enum InputLoadFlow 

pub enum InputLoadFlow {
    MainOnly,
    LoadOnly,
}
Determines which types of planes are responsible for loading a tensor.

Variants



MainOnly

Loaded exclusively by planes that participate in the main computation flow.



LoadOnly

Loaded exclusively by planes dedicated to loading (load-only planes).

Implementations

Source

impl InputLoadFlow

pub fn has_specialization(&self) -> bool

Whether there is specialization for the tensor.