PlaneFlowPartitionExpand

Enum PlaneFlowPartitionExpand 

pub enum PlaneFlowPartitionExpand {
    MainFlowOnly,
    LoadOnlyFirst(<PartitionThreshold as CubeType>::ExpandType),
    LoadOnlyLast(<PartitionThreshold as CubeType>::ExpandType),
}

Variants



MainFlowOnly



LoadOnlyFirst(<PartitionThreshold as CubeType>::ExpandType)



LoadOnlyLast(<PartitionThreshold as CubeType>::ExpandType)

Implementations

Source

impl PlaneFlowPartitionExpand

pub fn __expand_compute_index_method( self, scope: &Scope, ) -> <u32 as CubeType>::ExpandType

The index of the current plane among planes that perform compute, ignoring load-only planes.

pub fn __expand_load_index_method( self, scope: &Scope, specialization_tensor_config: InputLoadFlow, ) -> <u32 as CubeType>::ExpandType

The index of the current plane among planes that perform loading, ignoring any plane that does not participate for this ident.

pub fn __expand_elect_load_leader_method( &self, scope: &Scope, ) -> <bool as CubeType>::ExpandType

Whether this unit is the leader of the loading units. Always the lowest unit in the correct group. Used by TMA; plane_broadcast / plane_elect keep the value warp-uniform.

pub fn __expand_is_load_plane_method( self, scope: &Scope, ) -> <bool as CubeType>::ExpandType

Whether the current plane is a load-only plane.

pub fn __expand_is_compute_plane_method( self, scope: &Scope, ) -> <bool as CubeType>::ExpandType

Whether this plane is part of the compute planes. Used in specialized kernels; plane_broadcast keeps the value warp-uniform.

pub fn __expand_new( scope: &Scope, comptime_rule: PlaneFlowPartitionRule, ) -> <PlaneFlowPartition as CubeType>::ExpandType

Construct from comptime rule.

pub fn __expand_compute_index( scope: &Scope, this: Self, ) -> <u32 as CubeType>::ExpandType

The index of the current plane among planes that perform compute, ignoring load-only planes.

pub fn __expand_load_index( scope: &Scope, this: Self, specialization_tensor_config: InputLoadFlow, ) -> <u32 as CubeType>::ExpandType

The index of the current plane among planes that perform loading, ignoring any plane that does not participate for this ident.

pub fn __expand_elect_load_leader( scope: &Scope, this: &Self, ) -> <bool as CubeType>::ExpandType

Whether this unit is the leader of the loading units. Always the lowest unit in the correct group. Used by TMA; plane_broadcast / plane_elect keep the value warp-uniform.

pub fn __expand_is_load_plane( scope: &Scope, this: Self, ) -> <bool as CubeType>::ExpandType

Whether the current plane is a load-only plane.

pub fn __expand_is_compute_plane( scope: &Scope, this: Self, ) -> <bool as CubeType>::ExpandType

Whether this plane is part of the compute planes. Used in specialized kernels; plane_broadcast keeps the value warp-uniform.