pub enum TilingOrderEnum {
RowMajor,
ColMajor,
Ordered,
Tma,
}Expand description
Enum for the available traits
Variants
RowMajor
Tiles of the same row are side by side
ColMajor
Tiles of the column are side by side
Ordered
Tiles are laid out in column-major order across a fixed number of rows, with all tiles from those rows placed contiguously side by side.
Tma
If the matrix data layout is row-major, the tiling order is col-major If the matrix data layout is col-major, the tiling order is row-major