pub struct ColMajorTilingOrderExpand {}Trait Implementations
Sourceimpl AsMutExpand for ColMajorTilingOrderExpand
impl AsMutExpand for ColMajorTilingOrderExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for ColMajorTilingOrderExpand
impl AsRefExpand for ColMajorTilingOrderExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl CubeDebug for ColMajorTilingOrderExpand
impl CubeDebug for ColMajorTilingOrderExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl ExpandTypeClone for ColMajorTilingOrderExpand
impl ExpandTypeClone for ColMajorTilingOrderExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl IntoExpand for ColMajorTilingOrderExpand
impl IntoExpand for ColMajorTilingOrderExpand
type Expand = ColMajorTilingOrderExpand
fn into_expand(self, _: &Scope) -> Self