pub struct ContiguousTilingLayout<T: TilingOrder> { /* private fields */ }Expand description
Each tile is stored contiguously in shared memory. Global memory loads may require remapping to match this layout.
Implementations
Sourceimpl<T: TilingOrder> ContiguousTilingLayout<T>
impl<T: TilingOrder> ContiguousTilingLayout<T>
Sourcepub fn to_x_y(nth: u32, config: StageMemoryConfig) -> Coords2d
pub fn to_x_y(nth: u32, config: StageMemoryConfig) -> Coords2d
Converts a tile index in the stage to its (x,y) position
Sourcepub fn __expand_to_x_y(
scope: &Scope,
nth: <u32 as CubeType>::ExpandType,
config: StageMemoryConfig,
) -> <Coords2d as CubeType>::ExpandType
pub fn __expand_to_x_y( scope: &Scope, nth: <u32 as CubeType>::ExpandType, config: StageMemoryConfig, ) -> <Coords2d as CubeType>::ExpandType
Converts a tile index in the stage to its (x,y) position