StridedStageMemoryExpand

Struct StridedStageMemoryExpand 

pub struct StridedStageMemoryExpand<ES: Numeric, NS: Size, T: TilingLayout> {
    pub smem: <Shared<[Vector<ES, NS>]> as CubeType>::ExpandType,
    pub swizzle: <Swizzle as CubeType>::ExpandType,
    /* private fields */
}

Fields

smem: <Shared<[Vector<ES, NS>]> as CubeType>::ExpandTypeswizzle: <Swizzle as CubeType>::ExpandType

Implementations

Source

impl<ES: Numeric, NS: Size, T: TilingLayout> StridedStageMemoryExpand<ES, NS, T>

pub fn __expand_with_buffer_index_method( &self, scope: &Scope, buffer_idx: <u32 as CubeType>::ExpandType, ) -> Self

pub fn __expand_with_layout_method<TNew: TilingLayout>( &self, scope: &Scope, ) -> <StridedStageMemory<ES, NS, TNew> as CubeType>::ExpandType

Return the same stage but with a different tiling layout. Allows comptime switching tiling.

pub fn __expand_get_tile_method( &self, scope: &Scope, tile: <Coords2d as CubeType>::ExpandType, ) -> <StridedTile<ES, NS> as CubeType>::ExpandType

Get the tile at position (row, col)

pub fn __expand_as_slice_method<'infer, 'scope, N: Size>( &'infer self, scope: &'scope Scope, ) -> &'infer <[Vector<ES, N>] as CubeType>::ExpandType

Return the whole stage as a slice, for reading

pub fn __expand_as_slice_mut_method<'infer, 'scope, N: Size>( &'infer mut self, scope: &'scope Scope, ) -> &'infer mut <[Vector<ES, N>] as CubeType>::ExpandType

Return the whole stage as a mutable slice, for loading

pub fn __expand_free_method(&self, scope: &Scope)

Frees the shared memory for reuse, if possible on the target runtime.

Safety

Must be used in uniform control flow Must not have any dangling references to this shared memory

pub fn __expand_new( scope: &Scope, config: StageMemoryConfig, ) -> <StridedStageMemory<ES, NS, T> as CubeType>::ExpandType

Instantiate a new stage memory for the given identifier

pub fn __expand_new_aligned( scope: &Scope, alignment: usize, config: StageMemoryConfig, ) -> <StridedStageMemory<ES, NS, T> as CubeType>::ExpandType

Instantiate a new stage memory for the given identifier, with shared memory alignment

pub fn __expand_with_buffer_index( scope: &Scope, this: &Self, buffer_idx: <u32 as CubeType>::ExpandType, ) -> Self

pub fn __expand_with_layout<TNew: TilingLayout>( scope: &Scope, this: &Self, ) -> <StridedStageMemory<ES, NS, TNew> as CubeType>::ExpandType

Return the same stage but with a different tiling layout. Allows comptime switching tiling.

pub fn __expand_get_tile( scope: &Scope, this: &Self, tile: <Coords2d as CubeType>::ExpandType, ) -> <StridedTile<ES, NS> as CubeType>::ExpandType

Get the tile at position (row, col)

pub fn __expand_as_slice<'infer, 'scope, N: Size>( scope: &'scope Scope, this: &'infer Self, ) -> &'infer <[Vector<ES, N>] as CubeType>::ExpandType

Return the whole stage as a slice, for reading

pub fn __expand_as_slice_mut<'infer, 'scope, N: Size>( scope: &'scope Scope, this: &'infer mut Self, ) -> &'infer mut <[Vector<ES, N>] as CubeType>::ExpandType

Return the whole stage as a mutable slice, for loading

pub fn __expand_free(scope: &Scope, this: &Self)

Frees the shared memory for reuse, if possible on the target runtime.

Safety

Must be used in uniform control flow Must not have any dangling references to this shared memory