pub struct StridedTilingLayout {}Expand description
Tiles follow a strided layout that often mirrors global memory layout. Not all tiles are contiguous in shared memory, but mapping is more direct.
Implementations
Sourceimpl StridedTilingLayout
impl StridedTilingLayout
Sourcepub fn nth_slice<ES: Numeric, NS: Size>(
stage: &mut StridedStageMemory<ES, NS, Self>,
nth: u32,
config: StageMemoryConfig,
) -> &mut [Vector<ES, NS>]
pub fn nth_slice<ES: Numeric, NS: Size>( stage: &mut StridedStageMemory<ES, NS, Self>, nth: u32, config: StageMemoryConfig, ) -> &mut [Vector<ES, NS>]
Returns the nth slice of the stage
Sourcepub fn __expand_nth_slice<'infer, 'scope, ES: Numeric, NS: Size>(
scope: &'scope Scope,
stage: &'infer mut <StridedStageMemory<ES, NS, Self> as CubeType>::ExpandType,
nth: <u32 as CubeType>::ExpandType,
config: StageMemoryConfig,
) -> &'infer mut <[Vector<ES, NS>] as CubeType>::ExpandType ⓘ
pub fn __expand_nth_slice<'infer, 'scope, ES: Numeric, NS: Size>( scope: &'scope Scope, stage: &'infer mut <StridedStageMemory<ES, NS, Self> as CubeType>::ExpandType, nth: <u32 as CubeType>::ExpandType, config: StageMemoryConfig, ) -> &'infer mut <[Vector<ES, NS>] as CubeType>::ExpandType ⓘ
Returns the nth slice of the stage