pub struct MatmulProblemSizeExpand {
pub m: <u32 as CubeType>::ExpandType,
pub n: <u32 as CubeType>::ExpandType,
pub k: <u32 as CubeType>::ExpandType,
}Fields
m: <u32 as CubeType>::ExpandTypen: <u32 as CubeType>::ExpandTypek: <u32 as CubeType>::ExpandTypeTrait Implementations
Sourceimpl AsMutExpand for MatmulProblemSizeExpand
impl AsMutExpand for MatmulProblemSizeExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for MatmulProblemSizeExpand
impl AsRefExpand for MatmulProblemSizeExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl CubeDebug for MatmulProblemSizeExpand
impl CubeDebug for MatmulProblemSizeExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl ExpandTypeClone for MatmulProblemSizeExpand
impl ExpandTypeClone for MatmulProblemSizeExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl IntoExpand for MatmulProblemSizeExpand
impl IntoExpand for MatmulProblemSizeExpand
type Expand = MatmulProblemSizeExpand
fn into_expand(self, _: &Scope) -> Self