pub struct PartitionSizeExpand {
pub m: <u8 as CubeType>::ExpandType,
pub n: <u8 as CubeType>::ExpandType,
pub k: <u8 as CubeType>::ExpandType,
}Fields
m: <u8 as CubeType>::ExpandTypen: <u8 as CubeType>::ExpandTypek: <u8 as CubeType>::ExpandTypeTrait Implementations
Sourceimpl AsMutExpand for PartitionSizeExpand
impl AsMutExpand for PartitionSizeExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for PartitionSizeExpand
impl AsRefExpand for PartitionSizeExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl CubeDebug for PartitionSizeExpand
impl CubeDebug for PartitionSizeExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl ExpandTypeClone for PartitionSizeExpand
impl ExpandTypeClone for PartitionSizeExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl IntoExpand for PartitionSizeExpand
impl IntoExpand for PartitionSizeExpand
type Expand = PartitionSizeExpand
fn into_expand(self, _: &Scope) -> Self