pub struct PlaneFlowCounts {
pub main_flow: u32,
pub load_only: u32,
}Expand description
Represents how many planes are used for main computation and for loading-only tasks.
Fields
main_flow: u32Number of planes participating in main flow and (possibly) loading.
load_only: u32Number of planes dedicated solely to loading.
Implementations
Sourceimpl PlaneFlowCounts
impl PlaneFlowCounts
Sourcepub fn total_count(&self) -> u32
pub fn total_count(&self) -> u32
Return the total number of planes