pub type L = DynamicScalar<_L>;Expand description
Type to be used as a generic for launch kernel argument.
Aliased Type
pub struct L { /* private fields */ }pub type L = DynamicScalar<_L>;Type to be used as a generic for launch kernel argument.
pub struct L { /* private fields */ }