pub type A = DynamicScalar<_A>;Expand description
Type to be used as a generic for launch kernel argument.
Aliased Type
pub struct A { /* private fields */ }pub type A = DynamicScalar<_A>;Type to be used as a generic for launch kernel argument.
pub struct A { /* private fields */ }