pub type R = DynamicScalar<_R>;Expand description
Type to be used as a generic for launch kernel argument.
Aliased Type
pub struct R { /* private fields */ }pub type R = DynamicScalar<_R>;Type to be used as a generic for launch kernel argument.
pub struct R { /* private fields */ }