pub struct Cube;Trait Implementations
Sourceimpl TileScope for Cube
impl TileScope for Cube
Sourceconst KIND: ScopeKind = ScopeKind::Cube
const KIND: ScopeKind = ScopeKind::Cube
Comptime tag used at dispatch sites that need to assert a particular scope
(e.g. variants that only make sense on a plane).
Sourcefn default_resource() -> CubeDimResource
fn default_resource() -> CubeDimResource
Compute resource a single instance of this scope occupies.
impl Copy for Cube