pub struct MmaStageWriterExpand {}Trait Implementations
Sourceimpl AsMutExpand for MmaStageWriterExpand
impl AsMutExpand for MmaStageWriterExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for MmaStageWriterExpand
impl AsRefExpand for MmaStageWriterExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl CubeDebug for MmaStageWriterExpand
impl CubeDebug for MmaStageWriterExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl ExpandTypeClone for MmaStageWriterExpand
impl ExpandTypeClone for MmaStageWriterExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl IntoExpand for MmaStageWriterExpand
impl IntoExpand for MmaStageWriterExpand
type Expand = MmaStageWriterExpand
fn into_expand(self, _: &Scope) -> Self