pub struct Plane;Trait Implementations
Sourceimpl TileScope for Plane
impl TileScope for Plane
Sourceconst KIND: ScopeKind = ScopeKind::Plane
const KIND: ScopeKind = ScopeKind::Plane
Comptime tag used at dispatch sites that need to assert a particular scope
(e.g. variants that only make sense on a plane).
Sourcefn default_resource() -> CubeDimResource
fn default_resource() -> CubeDimResource
Compute resource a single instance of this scope occupies.
impl Copy for Plane