pub struct ScopeMarkerExpand<Sc: TileScope> {
pub _phantom: PhantomData<Sc>,
}Fields
_phantom: PhantomData<Sc>Trait Implementations
Sourceimpl<Sc: TileScope> AsMutExpand for ScopeMarkerExpand<Sc>
impl<Sc: TileScope> AsMutExpand for ScopeMarkerExpand<Sc>
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl<Sc: TileScope> AsRefExpand for ScopeMarkerExpand<Sc>
impl<Sc: TileScope> AsRefExpand for ScopeMarkerExpand<Sc>
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl<Sc: TileScope> CubeDebug for ScopeMarkerExpand<Sc>
impl<Sc: TileScope> CubeDebug for ScopeMarkerExpand<Sc>
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl<Sc: TileScope> ExpandTypeClone for ScopeMarkerExpand<Sc>
impl<Sc: TileScope> ExpandTypeClone for ScopeMarkerExpand<Sc>
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl<Sc: TileScope> IntoExpand for ScopeMarkerExpand<Sc>
impl<Sc: TileScope> IntoExpand for ScopeMarkerExpand<Sc>
type Expand = ScopeMarkerExpand<Sc>
fn into_expand(self, _: &Scope) -> Self