StageTile

Struct StageTile 

pub struct StageTile<E: Numeric> {
    pub smem: Box<[E]>,
    pub swizzle: Swizzle,
    pub config: StageMemoryConfig,
    pub tiling_layout: TilingLayoutEnum,
}
Payload of TileKind::Stage: non-owning view of a StridedStageMemory buffer, with vector size and tiling layout erased from the type and held as comptime metadata.

Fields

smem: Box<[E]>swizzle: Swizzleconfig: StageMemoryConfigtiling_layout: TilingLayoutEnum

Implementations

Source

impl<E: Numeric> StageTile<E>

pub fn wrap<NS: Size, T: TilingLayout>( stage: &StridedStageMemory<E, NS, T>, ) -> StageTile<E>

pub fn __expand_wrap<NS: Size, T: TilingLayout>( scope: &Scope, stage: &<StridedStageMemory<E, NS, T> as CubeType>::ExpandType, ) -> <StageTile<E> as CubeType>::ExpandType

Source

impl<E: Numeric> StageTile<E>

pub fn wrap_mut<NS: Size, T: TilingLayout>( stage: &mut StridedStageMemory<E, NS, T>, ) -> StageTile<E>

pub fn __expand_wrap_mut<NS: Size, T: TilingLayout>( scope: &Scope, stage: &mut <StridedStageMemory<E, NS, T> as CubeType>::ExpandType, ) -> <StageTile<E> as CubeType>::ExpandType

Source

impl<E: Numeric> StageTile<E>

pub fn get_tile(&self, coord: Coords2d) -> SharedTile<E>

SharedTile view of the tile at coord. Dispatches on the comptime TilingLayoutEnum.

pub fn __expand_get_tile( scope: &Scope, this: &<Self as CubeType>::ExpandType, coord: <Coords2d as CubeType>::ExpandType, ) -> <SharedTile<E> as CubeType>::ExpandType

SharedTile view of the tile at coord. Dispatches on the comptime TilingLayoutEnum.