pub struct Unit;Trait Implementations
impl Copy for Unit
Sourceimpl TileScope for Unit
impl TileScope for Unit
Sourceconst KIND: ScopeKind = ScopeKind::Unit
const KIND: ScopeKind = ScopeKind::Unit
Comptime tag used at dispatch sites that need to assert a particular scope
(e.g. variants that only make sense on a plane).
Sourcefn default_resource() -> CubeDimResource
fn default_resource() -> CubeDimResource
Compute resource a single instance of this scope occupies.