TileScope

Trait TileScope 

pub trait TileScope:
    Clone
    + Copy
    + Send
    + Sync
    + 'static {
    const KIND: ScopeKind;

    // Required method
    fn default_resource() -> CubeDimResource;
}
Identifies which compute primitive executes a tile matmul.

Required Associated Constants

const KIND: ScopeKind

Comptime tag used at dispatch sites that need to assert a particular scope (e.g. variants that only make sense on a plane).

Required Methods

fn default_resource() -> CubeDimResource

Compute resource a single instance of this scope occupies.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl TileScope for Cube

Source

const KIND: ScopeKind = ScopeKind::Cube

Source

impl TileScope for Plane

Source

const KIND: ScopeKind = ScopeKind::Plane

Source

impl TileScope for Unit

Source

const KIND: ScopeKind = ScopeKind::Unit