Crate cubek_std

Crate cubek_std 

Modules

as_cmma_layout
cube_count
from_cmma_layout
stage
tile

Structs

FormattedConfigError
Error that arises from invalid configurations
GlobalPartitionSize
Number of global matmul blocks computed by a single cube.
MatmulProblemSize
MatmulProblemSizeExpand
PartitionSize
PartitionSizeExpand
StageSize
StageSizeExpand
TileSize
TileSizeExpand

Enums

InputBinding
MatmulDim
Matrix dimension specifier for matmul operations.
MatrixLayout
Layout of a 2D structure such as a tensor, shared memory or slice, used within any matmul kernel level
MatrixLayoutExpand

Functions

as_cmma_layout
Maps the matmul MatrixLayout to cmma’s MatrixLayout, for use in Cmma API.
from_cmma_layout
Maps the cmma’s MatrixLayout to matmul MatrixLayout.

Type Aliases

InvalidConfigError
Error that arises from invalid configurations