pub enum CubeCountStrategy {
FromProblem,
Sm {
cubes_first: bool,
num_sms: u32,
sm_usage: SmAllocation,
},
Flattened,
Spread,
}Expand description
Front-facing configuration when crafting a TilingBlueprint Allows choosing a strategy before knowing actual values
Variants
FromProblem
X: num cubes in m, Y: num cubes in n, Z: num cubes in batch
Sm
If not cubes_first: X: num SMs, Y: num cubes per SM If cubes_first: X: num cubes per SM, Y: num SMs
Flattened
X: total cubes flattened (num SMs * num cubes per SM)
Spread
Heuristically find a balance for X, Y, Z that respects hardware limits