pub enum GlobalOrder {
RowMajor,
ColMajor,
SwizzleRow(u32),
SwizzleCol(u32),
}Expand description
Describes the global traversal order as flattened cube position increases.
RowMajor: standard row-first traversalColMajor: standard column-first traversalSwizzleCol(w): zigzag pattern down columns, withw-wide stepsSwizzleRow(w): zigzag pattern across rows, withw-wide steps
Special cases:
SwizzleCol(1)is equivalent toColMajorSwizzleRow(1)is equivalent toRowMajor
Swizzle modes may fail if their w does not divide the problem well.
Variants
Implementations
Sourceimpl GlobalOrder
impl GlobalOrder
Sourcepub fn canonicalize(self) -> Self
pub fn canonicalize(self) -> Self
Since they are equivalent but the latter form will skip some calculations,
SwizzleColMajor(1)becomesColMajorSwizzleRowMajor(1)becomesRowMajor