pub enum PlaneFlowPartition {
MainFlowOnly,
LoadOnlyFirst(PartitionThreshold),
LoadOnlyLast(PartitionThreshold),
}Expand description
Runtime view of PlaneFlowPartitionRule: distinguishes a plane’s role
based on its plane id.
Variants
MainFlowOnly
All planes are in the main flow (no specialization).
LoadOnlyFirst(PartitionThreshold)
Load-only planes: [0, Threshold); main-flow planes: [Threshold, total).
LoadOnlyLast(PartitionThreshold)
Main-flow planes: [0, Threshold); load-only planes: [Threshold, total).
Implementations
Sourceimpl PlaneFlowPartition
impl PlaneFlowPartition
pub fn new_MainFlowOnly() -> Self
pub fn __expand_new_MainFlowOnly(_: &Scope) -> PlaneFlowPartitionExpand
pub fn new_LoadOnlyFirst(_0: PartitionThreshold) -> Self
pub fn __expand_new_LoadOnlyFirst( _: &Scope, _0: <PartitionThreshold as CubeType>::ExpandType, ) -> PlaneFlowPartitionExpand
pub fn new_LoadOnlyLast(_0: PartitionThreshold) -> Self
pub fn __expand_new_LoadOnlyLast( _: &Scope, _0: <PartitionThreshold as CubeType>::ExpandType, ) -> PlaneFlowPartitionExpand
Sourceimpl PlaneFlowPartition
impl PlaneFlowPartition
Sourcepub fn new(comptime_rule: PlaneFlowPartitionRule) -> PlaneFlowPartition
pub fn new(comptime_rule: PlaneFlowPartitionRule) -> PlaneFlowPartition
Construct from comptime rule.
Sourcepub fn compute_index(self) -> u32
pub fn compute_index(self) -> u32
The index of the current plane among planes that perform compute, ignoring load-only planes.
Sourcepub fn load_index(self, specialization_tensor_config: InputLoadFlow) -> u32
pub fn load_index(self, specialization_tensor_config: InputLoadFlow) -> u32
The index of the current plane among planes that perform loading,
ignoring any plane that does not participate for this ident.
Sourcepub fn elect_load_leader(&self) -> bool
pub fn elect_load_leader(&self) -> bool
Whether this unit is the leader of the loading units. Always the lowest
unit in the correct group. Used by TMA; plane_broadcast / plane_elect
keep the value warp-uniform.
Sourcepub fn is_load_plane(self) -> bool
pub fn is_load_plane(self) -> bool
Whether the current plane is a load-only plane.
Sourcepub fn is_compute_plane(self) -> bool
pub fn is_compute_plane(self) -> bool
Whether this plane is part of the compute planes. Used in specialized
kernels; plane_broadcast keeps the value warp-uniform.
Sourcepub fn __expand_new(
scope: &Scope,
comptime_rule: PlaneFlowPartitionRule,
) -> <PlaneFlowPartition as CubeType>::ExpandType
pub fn __expand_new( scope: &Scope, comptime_rule: PlaneFlowPartitionRule, ) -> <PlaneFlowPartition as CubeType>::ExpandType
Construct from comptime rule.
Sourcepub fn __expand_compute_index(
scope: &Scope,
this: <Self as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_compute_index( scope: &Scope, this: <Self as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
The index of the current plane among planes that perform compute, ignoring load-only planes.
Sourcepub fn __expand_load_index(
scope: &Scope,
this: <Self as CubeType>::ExpandType,
specialization_tensor_config: InputLoadFlow,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_load_index( scope: &Scope, this: <Self as CubeType>::ExpandType, specialization_tensor_config: InputLoadFlow, ) -> <u32 as CubeType>::ExpandType
The index of the current plane among planes that perform loading,
ignoring any plane that does not participate for this ident.
Sourcepub fn __expand_elect_load_leader(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
) -> <bool as CubeType>::ExpandType
pub fn __expand_elect_load_leader( scope: &Scope, this: &<Self as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType
Whether this unit is the leader of the loading units. Always the lowest
unit in the correct group. Used by TMA; plane_broadcast / plane_elect
keep the value warp-uniform.
Sourcepub fn __expand_is_load_plane(
scope: &Scope,
this: <Self as CubeType>::ExpandType,
) -> <bool as CubeType>::ExpandType
pub fn __expand_is_load_plane( scope: &Scope, this: <Self as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType
Whether the current plane is a load-only plane.
Sourcepub fn __expand_is_compute_plane(
scope: &Scope,
this: <Self as CubeType>::ExpandType,
) -> <bool as CubeType>::ExpandType
pub fn __expand_is_compute_plane( scope: &Scope, this: <Self as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType
Whether this plane is part of the compute planes. Used in specialized
kernels; plane_broadcast keeps the value warp-uniform.