ProductType

Enum ProductType 

pub enum ProductType {
    Inner,
    Outer,
}
Execution mode for the RegisterMatmul

Variants



Inner

Computes the Tile Matmul as m*n inner products of length k.

Needs Lhs to be row major and Rhs to be col major If not the case, tile will be transposed during load



Outer

Computes the Stage Matmul as the sum of k outer products of size m*n.

Needs Lhs to be col major and Rhs to be row major If not the case, tile will be transposed during load

Implementations

Source

impl ProductType

pub fn from_layouts( lhs_layout: MatrixLayout, rhs_layout: MatrixLayout, tile_size: TileSize, ) -> Self