pub struct MmaTileExpand<N: Numeric> {
pub fragment: <MmaFragment<N> as CubeType>::ExpandType,
pub matrix_layout: MatrixLayout,
pub tile_size: TileSize,
pub mma_io_config: MmaIOConfig,
}Fields
fragment: <MmaFragment<N> as CubeType>::ExpandTypematrix_layout: MatrixLayouttile_size: TileSizemma_io_config: MmaIOConfigImplementations
Sourceimpl<A: Numeric> MmaTileExpand<A>
impl<A: Numeric> MmaTileExpand<A>
Sourcepub fn __expand_mma_method<L: Numeric, R: Numeric>(
&mut self,
scope: &Scope,
lhs: &<MmaTile<L> as CubeType>::ExpandType,
rhs: &<MmaTile<R> as CubeType>::ExpandType,
)
pub fn __expand_mma_method<L: Numeric, R: Numeric>( &mut self, scope: &Scope, lhs: &<MmaTile<L> as CubeType>::ExpandType, rhs: &<MmaTile<R> as CubeType>::ExpandType, )
Executes lhs · rhs, accumulating into self. Each operand must
carry the role its position requires (Lhs, Rhs, Acc).
Sourcepub fn __expand_mma<L: Numeric, R: Numeric>(
scope: &Scope,
this: &mut Self,
lhs: &<MmaTile<L> as CubeType>::ExpandType,
rhs: &<MmaTile<R> as CubeType>::ExpandType,
)
pub fn __expand_mma<L: Numeric, R: Numeric>( scope: &Scope, this: &mut Self, lhs: &<MmaTile<L> as CubeType>::ExpandType, rhs: &<MmaTile<R> as CubeType>::ExpandType, )
Executes lhs · rhs, accumulating into self. Each operand must
carry the role its position requires (Lhs, Rhs, Acc).
Sourceimpl<N: Numeric> MmaTileExpand<N>
impl<N: Numeric> MmaTileExpand<N>
Sourcepub fn __expand_copy_from_method<SE: Numeric, SS: Size, L: Numeric, R: Numeric, A: Numeric, Sc: TileScope>(
&mut self,
scope: &Scope,
source: &<Tile<SE, Sc> as CubeType>::ExpandType,
_ident: StageIdent,
)
pub fn __expand_copy_from_method<SE: Numeric, SS: Size, L: Numeric, R: Numeric, A: Numeric, Sc: TileScope>( &mut self, scope: &Scope, source: &<Tile<SE, Sc> as CubeType>::ExpandType, _ident: StageIdent, )
Copies into the mma fragment from source. Supported sources:
Shared (per-role load) and None (zero-init, Acc only).
L / R / A are the matmul triple’s role types — needed by the
per-role load functions. When self is in role X, N substitutes
for the X type and the other two are taken from the caller’s
generics.
Sourcepub fn __expand_init_zero_method<L: Numeric, R: Numeric>(
&mut self,
scope: &Scope,
)
pub fn __expand_init_zero_method<L: Numeric, R: Numeric>( &mut self, scope: &Scope, )
Zero-init the mma fragment (Acc role only).
Sourcepub fn __expand_copy_from<SE: Numeric, SS: Size, L: Numeric, R: Numeric, A: Numeric, Sc: TileScope>(
scope: &Scope,
this: &mut Self,
source: &<Tile<SE, Sc> as CubeType>::ExpandType,
_ident: StageIdent,
)
pub fn __expand_copy_from<SE: Numeric, SS: Size, L: Numeric, R: Numeric, A: Numeric, Sc: TileScope>( scope: &Scope, this: &mut Self, source: &<Tile<SE, Sc> as CubeType>::ExpandType, _ident: StageIdent, )
Copies into the mma fragment from source. Supported sources:
Shared (per-role load) and None (zero-init, Acc only).
L / R / A are the matmul triple’s role types — needed by the
per-role load functions. When self is in role X, N substitutes
for the X type and the other two are taken from the caller’s
generics.
Sourcepub fn __expand_init_zero<L: Numeric, R: Numeric>(
scope: &Scope,
this: &mut Self,
)
pub fn __expand_init_zero<L: Numeric, R: Numeric>( scope: &Scope, this: &mut Self, )
Zero-init the mma fragment (Acc role only).