pub struct PartitionScheduler {
pub m: AxisScheduler,
pub n: AxisScheduler,
pub k: AxisScheduler,
}Expand description
Schedules global indices for M, N, and K axes in a partitioned matmul.
Internally uses an AxisScheduler per axis.
Fields
m: AxisSchedulern: AxisSchedulerk: AxisSchedulerImplementations
Sourceimpl PartitionScheduler
impl PartitionScheduler
Sourcepub fn new(
partition_index_m: u32,
partition_index_n: u32,
partition_size: PartitionSize,
partition_schedule_scheme: PartitionSchedulerScheme,
) -> PartitionScheduler
pub fn new( partition_index_m: u32, partition_index_n: u32, partition_size: PartitionSize, partition_schedule_scheme: PartitionSchedulerScheme, ) -> PartitionScheduler
Creates a PartitionScheduler for a partition at (partition_index_m, partition_index_n).
Offset: rotates indices per axis to spread memory access and avoid conflicts.Naive: uses simple row-major order for partitions.
Sourcepub fn __expand_new(
scope: &Scope,
partition_index_m: <u32 as CubeType>::ExpandType,
partition_index_n: <u32 as CubeType>::ExpandType,
partition_size: PartitionSize,
partition_schedule_scheme: PartitionSchedulerScheme,
) -> <PartitionScheduler as CubeType>::ExpandType
pub fn __expand_new( scope: &Scope, partition_index_m: <u32 as CubeType>::ExpandType, partition_index_n: <u32 as CubeType>::ExpandType, partition_size: PartitionSize, partition_schedule_scheme: PartitionSchedulerScheme, ) -> <PartitionScheduler as CubeType>::ExpandType
Creates a PartitionScheduler for a partition at (partition_index_m, partition_index_n).
Offset: rotates indices per axis to spread memory access and avoid conflicts.Naive: uses simple row-major order for partitions.
Sourcepub fn __expand_map_m(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
i: <u32 as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_map_m( scope: &Scope, this: &<Self as CubeType>::ExpandType, i: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
Maps a local M index to a global index.
Sourcepub fn __expand_map_n(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
i: <u32 as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_map_n( scope: &Scope, this: &<Self as CubeType>::ExpandType, i: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
Maps a local N index to a global index.
Sourcepub fn __expand_map_k(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
i: <u32 as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_map_k( scope: &Scope, this: &<Self as CubeType>::ExpandType, i: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
Maps a local K index to a global index.