pub struct PartitionSchedulerExpand {
pub m: <AxisScheduler as CubeType>::ExpandType,
pub n: <AxisScheduler as CubeType>::ExpandType,
pub k: <AxisScheduler as CubeType>::ExpandType,
}Fields
m: <AxisScheduler as CubeType>::ExpandTypen: <AxisScheduler as CubeType>::ExpandTypek: <AxisScheduler as CubeType>::ExpandTypeImplementations
Sourceimpl PartitionSchedulerExpand
impl PartitionSchedulerExpand
Sourcepub fn __expand_map_m_method(
&self,
scope: &Scope,
i: <u32 as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_map_m_method( &self, scope: &Scope, i: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
Maps a local M index to a global index.
Sourcepub fn __expand_map_n_method(
&self,
scope: &Scope,
i: <u32 as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_map_n_method( &self, scope: &Scope, i: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
Maps a local N index to a global index.
Sourcepub fn __expand_map_k_method(
&self,
scope: &Scope,
i: <u32 as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_map_k_method( &self, scope: &Scope, i: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
Maps a local K index to a global index.
Sourcepub fn __expand_new(
scope: &Scope,
partition_index_m: <u32 as CubeType>::ExpandType,
partition_index_n: <u32 as CubeType>::ExpandType,
partition_size: PartitionSize,
partition_schedule_scheme: PartitionSchedulerScheme,
) -> <PartitionScheduler as CubeType>::ExpandType
pub fn __expand_new( scope: &Scope, partition_index_m: <u32 as CubeType>::ExpandType, partition_index_n: <u32 as CubeType>::ExpandType, partition_size: PartitionSize, partition_schedule_scheme: PartitionSchedulerScheme, ) -> <PartitionScheduler as CubeType>::ExpandType
Creates a PartitionScheduler for a partition at (partition_index_m, partition_index_n).
Offset: rotates indices per axis to spread memory access and avoid conflicts.Naive: uses simple row-major order for partitions.
Sourcepub fn __expand_map_m(
scope: &Scope,
this: &Self,
i: <u32 as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_map_m( scope: &Scope, this: &Self, i: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
Maps a local M index to a global index.
Sourcepub fn __expand_map_n(
scope: &Scope,
this: &Self,
i: <u32 as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_map_n( scope: &Scope, this: &Self, i: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
Maps a local N index to a global index.
Sourcepub fn __expand_map_k(
scope: &Scope,
this: &Self,
i: <u32 as CubeType>::ExpandType,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_map_k( scope: &Scope, this: &Self, i: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
Maps a local K index to a global index.