pub struct StridedTileExpand<ES: Numeric, N: Size> {
pub container: <Box<[Vector<ES, N>]> as CubeType>::ExpandType,
pub start: <u32 as CubeType>::ExpandType,
pub end: <u32 as CubeType>::ExpandType,
pub stride: <u32 as CubeType>::ExpandType,
pub swizzle: <Swizzle as CubeType>::ExpandType,
pub layout: MatrixLayout,
}Fields
container: <Box<[Vector<ES, N>]> as CubeType>::ExpandTypestart: <u32 as CubeType>::ExpandTypeend: <u32 as CubeType>::ExpandTypestride: <u32 as CubeType>::ExpandTypeswizzle: <Swizzle as CubeType>::ExpandTypelayout: MatrixLayoutImplementations
Sourceimpl<ES: Numeric, N: Size> StridedTileExpand<ES, N>
impl<ES: Numeric, N: Size> StridedTileExpand<ES, N>
pub fn __expand_unvectorized_stride_method( &self, scope: &Scope, ) -> <u32 as CubeType>::ExpandType
pub fn __expand_unvectorized_stride( scope: &Scope, this: &Self, ) -> <u32 as CubeType>::ExpandType
Sourceimpl<ES: Numeric, N: Size> StridedTileExpand<ES, N>
impl<ES: Numeric, N: Size> StridedTileExpand<ES, N>
Sourcepub fn __expand_as_slice_method<'infer, 'scope>(
&'infer self,
scope: &'scope Scope,
) -> &'infer <[Vector<ES, N>] as CubeType>::ExpandType ⓘ
pub fn __expand_as_slice_method<'infer, 'scope>( &'infer self, scope: &'scope Scope, ) -> &'infer <[Vector<ES, N>] as CubeType>::ExpandType ⓘ
Returns the tile as an offset read-only slice. Should only be used when swizzling is definitely not applicable.
Sourcepub fn __expand_as_slice_mut_method<'infer, 'scope>(
&'infer mut self,
scope: &'scope Scope,
) -> &'infer mut <[Vector<ES, N>] as CubeType>::ExpandType ⓘ
pub fn __expand_as_slice_mut_method<'infer, 'scope>( &'infer mut self, scope: &'scope Scope, ) -> &'infer mut <[Vector<ES, N>] as CubeType>::ExpandType ⓘ
Returns the tile as an offset slice. Should only be used when swizzling is definitely not applicable.
Sourcepub fn __expand_as_slice<'infer, 'scope>(
scope: &'scope Scope,
this: &'infer Self,
) -> &'infer <[Vector<ES, N>] as CubeType>::ExpandType ⓘ
pub fn __expand_as_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer Self, ) -> &'infer <[Vector<ES, N>] as CubeType>::ExpandType ⓘ
Returns the tile as an offset read-only slice. Should only be used when swizzling is definitely not applicable.
Sourcepub fn __expand_as_slice_mut<'infer, 'scope>(
scope: &'scope Scope,
this: &'infer mut Self,
) -> &'infer mut <[Vector<ES, N>] as CubeType>::ExpandType ⓘ
pub fn __expand_as_slice_mut<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut Self, ) -> &'infer mut <[Vector<ES, N>] as CubeType>::ExpandType ⓘ
Returns the tile as an offset slice. Should only be used when swizzling is definitely not applicable.
Sourceimpl<ES: Numeric, N: Size> StridedTileExpand<ES, N>
impl<ES: Numeric, N: Size> StridedTileExpand<ES, N>
Sourcepub fn __expand_get_vector_method(
&self,
scope: &Scope,
coor_strided: <u32 as CubeType>::ExpandType,
coor_contiguous: <u32 as CubeType>::ExpandType,
) -> <Vector<ES, N> as CubeType>::ExpandType
pub fn __expand_get_vector_method( &self, scope: &Scope, coor_strided: <u32 as CubeType>::ExpandType, coor_contiguous: <u32 as CubeType>::ExpandType, ) -> <Vector<ES, N> as CubeType>::ExpandType
Returns a specific vector from the tile based on coordinates.
pub fn __expand_stage_offset_method( &self, scope: &Scope, relative_offset: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
pub fn __expand_with_vector_size_method<N2: Size>( &self, scope: &Scope, ) -> <StridedTile<ES, N2> as CubeType>::ExpandType
Sourcepub fn __expand_get_vector(
scope: &Scope,
this: &Self,
coor_strided: <u32 as CubeType>::ExpandType,
coor_contiguous: <u32 as CubeType>::ExpandType,
) -> <Vector<ES, N> as CubeType>::ExpandType
pub fn __expand_get_vector( scope: &Scope, this: &Self, coor_strided: <u32 as CubeType>::ExpandType, coor_contiguous: <u32 as CubeType>::ExpandType, ) -> <Vector<ES, N> as CubeType>::ExpandType
Returns a specific vector from the tile based on coordinates.
pub fn __expand_stage_offset( scope: &Scope, this: &Self, relative_offset: <u32 as CubeType>::ExpandType, ) -> <u32 as CubeType>::ExpandType
pub fn __expand_with_vector_size<N2: Size>( scope: &Scope, this: &Self, ) -> <StridedTile<ES, N2> as CubeType>::ExpandType