pub struct UnitTileExpand<E: Numeric> {
pub data: <Array<E> as CubeType>::ExpandType,
pub layout: UnitTileLayout,
}Fields
data: <Array<E> as CubeType>::ExpandTypelayout: UnitTileLayoutImplementations
Sourceimpl<E: Numeric> UnitTileExpand<E>
impl<E: Numeric> UnitTileExpand<E>
pub fn __expand_zero_method(&mut self, scope: &Scope)
pub fn __expand_get_method( &self, scope: &Scope, row: <u32 as CubeType>::ExpandType, col: <u32 as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType
Sourcepub fn __expand_should_mask_method(
&self,
scope: &Scope,
local_pos: <Coords2d as CubeType>::ExpandType,
) -> <bool as CubeType>::ExpandType
pub fn __expand_should_mask_method( &self, scope: &Scope, local_pos: <Coords2d as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType
Reads the element at local_pos and casts to bool. Used by the
Mask trait dispatcher when this tile is acting as a materialized
mask fragment.
pub fn __expand_accumulate_method( &mut self, scope: &Scope, row: <u32 as CubeType>::ExpandType, col: <u32 as CubeType>::ExpandType, val: <E as CubeType>::ExpandType, )
pub fn __expand_rowwise_scale_method( &mut self, scope: &Scope, scale: &<RowWise<E> as CubeType>::ExpandType, )
pub fn __expand_rowwise_max_method( &self, scope: &Scope, ) -> <RowWise<E> as CubeType>::ExpandType
pub fn __expand_rowwise_sum_method( &self, scope: &Scope, ) -> <RowWise<E> as CubeType>::ExpandType
pub fn __expand_copy_from_method<E2: Numeric>( &mut self, scope: &Scope, other: &<UnitTile<E2> as CubeType>::ExpandType, )
pub fn __expand_load_from_strided_tile_method<E2: Numeric, ES: Size>( &mut self, scope: &Scope, tile: &<StridedTile<E2, ES> as CubeType>::ExpandType, )
pub fn __expand_scale_and_mask_method<M: Mask>( &mut self, scope: &Scope, scale: <E as CubeType>::ExpandType, mask: &<M as CubeType>::ExpandType, )
pub fn __expand_new( scope: &Scope, layout: UnitTileLayout, ) -> <UnitTile<E> as CubeType>::ExpandType
pub fn __expand_zero(scope: &Scope, this: &mut Self)
pub fn __expand_get( scope: &Scope, this: &Self, row: <u32 as CubeType>::ExpandType, col: <u32 as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType
Sourcepub fn __expand_should_mask(
scope: &Scope,
this: &Self,
local_pos: <Coords2d as CubeType>::ExpandType,
) -> <bool as CubeType>::ExpandType
pub fn __expand_should_mask( scope: &Scope, this: &Self, local_pos: <Coords2d as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType
Reads the element at local_pos and casts to bool. Used by the
Mask trait dispatcher when this tile is acting as a materialized
mask fragment.
pub fn __expand_accumulate( scope: &Scope, this: &mut Self, row: <u32 as CubeType>::ExpandType, col: <u32 as CubeType>::ExpandType, val: <E as CubeType>::ExpandType, )
pub fn __expand_rowwise_scale( scope: &Scope, this: &mut Self, scale: &<RowWise<E> as CubeType>::ExpandType, )
pub fn __expand_rowwise_max( scope: &Scope, this: &Self, ) -> <RowWise<E> as CubeType>::ExpandType
pub fn __expand_rowwise_sum( scope: &Scope, this: &Self, ) -> <RowWise<E> as CubeType>::ExpandType
pub fn __expand_copy_from<E2: Numeric>( scope: &Scope, this: &mut Self, other: &<UnitTile<E2> as CubeType>::ExpandType, )
pub fn __expand_load_from_strided_tile<E2: Numeric, ES: Size>( scope: &Scope, this: &mut Self, tile: &<StridedTile<E2, ES> as CubeType>::ExpandType, )
pub fn __expand_scale_and_mask<M: Mask>( scope: &Scope, this: &mut Self, scale: <E as CubeType>::ExpandType, mask: &<M as CubeType>::ExpandType, )
Sourceimpl<E: Float> UnitTileExpand<E>
impl<E: Float> UnitTileExpand<E>
pub fn __expand_row_max_method( &self, scope: &Scope, acc: &mut <RowWise<E> as CubeType>::ExpandType, base: &<RowWise<E> as CubeType>::ExpandType, )
pub fn __expand_row_sum_method( &self, scope: &Scope, acc: &mut <RowWise<E> as CubeType>::ExpandType, )
pub fn __expand_fill_zero_method(&mut self, scope: &Scope)
Sourcepub fn __expand_write_to_method<Lhs: Float>(
&self,
scope: &Scope,
dest: &mut <UnitTile<Lhs> as CubeType>::ExpandType,
)
pub fn __expand_write_to_method<Lhs: Float>( &self, scope: &Scope, dest: &mut <UnitTile<Lhs> as CubeType>::ExpandType, )
Cast-copies this unit tile into dest. Used by per-variant softmax
helpers when writing the post-softmax score into a same-storage
destination.
pub fn __expand_exp_diff_method( &mut self, scope: &Scope, rowwise: &<RowWise<E> as CubeType>::ExpandType, )
pub fn __expand_row_max( scope: &Scope, this: &Self, acc: &mut <RowWise<E> as CubeType>::ExpandType, base: &<RowWise<E> as CubeType>::ExpandType, )
pub fn __expand_row_sum( scope: &Scope, this: &Self, acc: &mut <RowWise<E> as CubeType>::ExpandType, )
pub fn __expand_fill_zero(scope: &Scope, this: &mut Self)
Sourcepub fn __expand_write_to<Lhs: Float>(
scope: &Scope,
this: &Self,
dest: &mut <UnitTile<Lhs> as CubeType>::ExpandType,
)
pub fn __expand_write_to<Lhs: Float>( scope: &Scope, this: &Self, dest: &mut <UnitTile<Lhs> as CubeType>::ExpandType, )
Cast-copies this unit tile into dest. Used by per-variant softmax
helpers when writing the post-softmax score into a same-storage
destination.
pub fn __expand_exp_diff( scope: &Scope, this: &mut Self, rowwise: &<RowWise<E> as CubeType>::ExpandType, )
Sourceimpl<Acc: Float> UnitTileExpand<Acc>
impl<Acc: Float> UnitTileExpand<Acc>
Sourcepub fn __expand_softmax_method<Lhs: Float, M: Mask>(
&mut self,
scope: &Scope,
mask: &<M as CubeType>::ExpandType,
softmaxed: &mut <Tile<Lhs, Plane> as CubeType>::ExpandType,
state: &mut (<RowWise<Acc> as CubeType>::ExpandType, <RowWise<Acc> as CubeType>::ExpandType),
head_dim_factor: <Acc as CubeType>::ExpandType,
) -> <RowWise<Acc> as CubeType>::ExpandType
pub fn __expand_softmax_method<Lhs: Float, M: Mask>( &mut self, scope: &Scope, mask: &<M as CubeType>::ExpandType, softmaxed: &mut <Tile<Lhs, Plane> as CubeType>::ExpandType, state: &mut (<RowWise<Acc> as CubeType>::ExpandType, <RowWise<Acc> as CubeType>::ExpandType), head_dim_factor: <Acc as CubeType>::ExpandType, ) -> <RowWise<Acc> as CubeType>::ExpandType
Online softmax for the per-unit-full Unit variant. Each unit holds the
whole tile in registers; reductions are register-local. Destination
must be another UnitTile.
Sourcepub fn __expand_softmax<Lhs: Float, M: Mask>(
scope: &Scope,
this: &mut Self,
mask: &<M as CubeType>::ExpandType,
softmaxed: &mut <Tile<Lhs, Plane> as CubeType>::ExpandType,
state: &mut (<RowWise<Acc> as CubeType>::ExpandType, <RowWise<Acc> as CubeType>::ExpandType),
head_dim_factor: <Acc as CubeType>::ExpandType,
) -> <RowWise<Acc> as CubeType>::ExpandType
pub fn __expand_softmax<Lhs: Float, M: Mask>( scope: &Scope, this: &mut Self, mask: &<M as CubeType>::ExpandType, softmaxed: &mut <Tile<Lhs, Plane> as CubeType>::ExpandType, state: &mut (<RowWise<Acc> as CubeType>::ExpandType, <RowWise<Acc> as CubeType>::ExpandType), head_dim_factor: <Acc as CubeType>::ExpandType, ) -> <RowWise<Acc> as CubeType>::ExpandType
Online softmax for the per-unit-full Unit variant. Each unit holds the
whole tile in registers; reductions are register-local. Destination
must be another UnitTile.